==> ejc-hrmanage-impl-3.0.0-20251204.095435-195-sources.jar: com/ejianc/business/hr/service/impl/BaseOrgServiceImpl.java <==
package com.ejianc.business.hr.service.impl;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.hr.bean.BaseOrgEntity;
import com.ejianc.business.hr.bean.BaseUserEntity;
import com.ejianc.business.hr.mapper.BaseOrgMapper;
import com.ejianc.business.hr.mapper.BaseUserMapper;
import com.ejianc.business.hr.mapper.SalaryUserMapper;
import com.ejianc.business.hr.service.IBaseOrgService;
import com.ejianc.business.hr.service.IBaseUserService;
import com.ejianc.business.hr.vo.*;
import com.ejianc.business.hr.vo.salarySystem.SalaryAttendanceDataVO;
import com.ejianc.business.hr.vo.salarySystem.SalaryJobDataVO;
import com.ejianc.business.hr.vo.salarySystem.SalaryTransferDataVO;
import com.ejianc.business.hr.vo.salarySystem.SalaryUserDataVO;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

/**
 * 人力基础人员信息
 *
 * @author generator
 */
@Service("baseOrgService")
public class BaseOrgServiceImpl extends BaseServiceImpl<BaseOrgMapper, BaseOrgEntity> implements IBaseOrgService {

    @Autowired
    private BaseOrgMapper mapper;

    @Override
    public List<OrgDataVO> refAllOrgData(Map<String, Object> params) {
        return mapper.refAllOrgData(params);
    }
    @Override
    public List<OrgDataVO> refAllDictData(Map<String, Object> params) {
        return mapper.refAllDictData(params);
    }
}

==> ejc-hrmanage-impl-3.0.0-20251210.072154-198-sources.jar: com/ejianc/business/hr/service/impl/BaseOrgServiceImpl.java <==
package com.ejianc.business.hr.service.impl;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.business.hr.bean.BaseOrgEntity;
import com.ejianc.business.hr.bean.BaseUserEntity;
import com.ejianc.business.hr.mapper.BaseOrgMapper;
import com.ejianc.business.hr.mapper.BaseUserMapper;
import com.ejianc.business.hr.mapper.SalaryUserMapper;
import com.ejianc.business.hr.service.IBaseOrgService;
import com.ejianc.business.hr.service.IBaseUserService;
import com.ejianc.business.hr.vo.*;
import com.ejianc.business.hr.vo.hrm.UserJobVO;
import com.ejianc.business.hr.vo.salarySystem.SalaryAttendanceDataVO;
import com.ejianc.business.hr.vo.salarySystem.SalaryJobDataVO;
import com.ejianc.business.hr.vo.salarySystem.SalaryTransferDataVO;
import com.ejianc.business.hr.vo.salarySystem.SalaryUserDataVO;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

/**
 * 人力基础人员信息
 *
 * @author generator
 */
@Service("baseOrgService")
public class BaseOrgServiceImpl extends BaseServiceImpl<BaseOrgMapper, BaseOrgEntity> implements IBaseOrgService {

    @Autowired
    private BaseOrgMapper mapper;

    @Override
    public List<OrgDataVO> refAllOrgData(Map<String, Object> params) {
        return mapper.refAllOrgData(params);
    }
    @Override
    public List<OrgDataVO> refAllDictData(Map<String, Object> params) {
        return mapper.refAllDictData(params);
    }

    @Override
    public List<UserJobVO> refPartTimeUserList(String userCode,String jobState) {
        return mapper.refPartTimeUserList(userCode,jobState);
    }
}
